@@ -2,8 +2,8 @@
 #' 
 #' \code{hima} is used to estimate and test high-dimensional mediation effects.
 #' 
-#' @param X a vector of exposure. 
-#' @param Y a vector of outcome. Can be either continuous or binary (0-1).
+#' @param X a vector of exposure. Do not use data.frame or matrix.
+#' @param Y a vector of outcome. Can be either continuous or binary (0-1). Do not use data.frame or matrix.
 #' @param M a \code{data.frame} or \code{matrix} of high-dimensional mediators. Rows represent samples, columns 
 #' represent variables.
 #' @param COV.XM a \code{data.frame} or \code{matrix} of covariates dataset for testing the association \code{M ~ X}. 
@@ -12,17 +12,15 @@
 #' @param COV.MY a \code{data.frame} or \code{matrix} of covariates dataset for testing the association \code{Y ~ M}. 
 #' Covariates specified here will not participate penalization. If not specified, the same set of covariates for 
 #' \code{M ~ X} will be applied. Using different sets of covariates is allowed but this needs to be handled carefully.
-#' @param family either 'gaussian' or 'binomial', depending on the data type of outcome (\code{Y}). See 
+#' @param Y.family either 'gaussian' (default) or 'binomial', depending on the data type of outcome (\code{Y}). See 
 #' \code{\link{ncvreg}}
-#' @param screen.family either 'gaussian' (default) or 'negbin' (i.e., negative binomial). This parameter is 
-#' taking effect only when parameter \code{family = 'binomial'}. When \code{family = 'binomial'}, the screening step
-#' is based on X (exposure, independent variable) and the omic mediator (dependent variable). This is useful when
-#' handling RNA sequencing count data as mediators.   
+#' @param M.family either 'gaussian' (default) or 'negbin' (i.e., negative binomial), depending on the data type of
+#' mediator (\code{M}).
 #' @param penalty the penalty to be applied to the model. Either 'MCP' (the default), 'SCAD', or 
 #' 'lasso'. See \code{\link{ncvreg}}.
 #' @param topN an integer specifying the number of top markers from sure independent screening. 
 #' Default = \code{NULL}. If \code{NULL}, \code{topN} will be either \code{ceiling(n/log(n))} if 
-#' \code{family = 'gaussian'}, or \code{ceiling(n/(2*log(n)))} if \code{family = 'binomial'}, 
+#' \code{Y.family = 'gaussian'}, or \code{ceiling(n/(2*log(n)))} if \code{Y.family = 'binomial'}, 
 #' where \code{n} is the sample size. If the sample size is greater than topN (pre-specified or calculated), all 
 #' mediators will be included in the test (i.e. low-dimensional scenario).
 #' @param parallel logical. Enable parallel computing feature? Default = \code{TRUE}.
@@ -47,7 +45,7 @@
 #' Bioinformatics. 2016. DOI: 10.1093/bioinformatics/btw351. PMID: 27357171. PMCID: PMC5048064
 #' 
 #' @examples
-#' n <- 200  # sample size
+#' n <- 200 # sample size
 #' p <- 200 # the dimension of covariates
 #' 
 #' # the regression coefficients alpha (exposure --> mediators)
@@ -76,33 +74,33 @@
 #' hima.fit <- hima(simdat_cont$X, simdat_cont$Y, simdat_cont$M, verbose = TRUE) 
 #' hima.fit
 #' 
-#' # When Y is binary (should specify family)
+#' # When Y is binary (should specify Y.family)
 #' hima.logistic.fit <- hima(simdat_bin$X, simdat_bin$Y, simdat_bin$M, 
-#' family = "binomial", verbose = TRUE) 
+#' Y.family = "binomial", verbose = TRUE) 
 #' hima.logistic.fit
 #' 
 #' @export
 hima <- function(X, Y, M, COV.XM = NULL, COV.MY = COV.XM, 
-                 family = c("gaussian", "binomial"), 
-                 screen.family = c("gaussian", "negbin"), 
+                 Y.family = c("gaussian", "binomial"), 
+                 M.family = c("gaussian", "negbin"), 
                  penalty = c("MCP", "SCAD", "lasso"), 
                  topN = NULL, 
                  parallel = FALSE, 
                  ncore = 1, 
                  verbose = FALSE, 
                  ...) {
-    family <- match.arg(family)
-    screen.family <- match.arg(screen.family)
+    Y.family <- match.arg(Y.family)
+    M.family <- match.arg(M.family)
     penalty <- match.arg(penalty)
     
-    if (parallel & (ncore == 1)) ncore <- parallel::detectCores()
-    if (!parallel & (ncore > 1)) parallel = TRUE
+    if(parallel & (ncore == 1)) ncore <- parallel::detectCores()
+    if(!parallel & (ncore > 1)) parallel = TRUE
     
     n <- nrow(M)
     p <- ncol(M)
     
-    if (is.null(topN)) {
-      if (family == "binomial") d <- ceiling(n/(2*log(n))) else d <- ceiling(2 * n/log(n)) 
+    if(is.null(topN)) {
+      if(Y.family == "binomial") d <- ceiling(n/(2*log(n))) else d <- ceiling(2 * n/log(n)) 
     } else {
       d <- topN  # the number of top mediators that associated with exposure (X)
     }
@@ -114,24 +112,23 @@ hima <- function(X, Y, M, COV.XM = NULL, COV.MY = COV.XM,
     #########################################################################
     message("Step 1: Sure Independent Screening ...", "     (", Sys.time(), ")")
     
-    if(family == "binomial")
+    if(Y.family == "binomial")
     {
       # Screen M using X given the limited information provided by Y (binary)
-      # Therefore the family is still gaussian by default (can be negative binomial only when
-      # family == "binomial")
-      if(verbose) message("    Screening M using the association between X and M: ", appendLF = FALSE)
-      alpha = SIS_Results <- himasis(NA, M, X, COV.XM, glm.family = screen.family, modelstatement = "Mone ~ X", 
-                               parallel = parallel, ncore = ncore, verbose, tag = "Sure Independent Screening")
+      if(verbose) message("    Screening M using the association between X (independent variable) and M (dependent variable): ", appendLF = FALSE)
+      alpha = SIS_Results <- himasis(NA, M, X, COV.XM, glm.family = M.family, modelstatement = "Mone ~ X", 
+                               parallel = parallel, ncore = ncore, verbose, tag = paste0("Sure Independent Screening (M ~ X + COV.XM, family: ", M.family, ")"))
       SIS_Pvalue <- SIS_Results[2,]
-    } else if (family == "gaussian"){
+    } else if(Y.family == "gaussian"){
       # Screen M using Y (continuous)
-      if(verbose) message("    Screening M using the association between M and Y: ", appendLF = FALSE)
-      SIS_Results <- himasis(Y, M, X, COV.MY, glm.family = family, modelstatement = "Y ~ Mone + X", 
-                               parallel = parallel, ncore = ncore, verbose, tag = "Sure Independent Screening")
+      if(verbose) message("    Screening M using the association between M (independent variable) and Y (dependent variable): ", appendLF = FALSE)
+      SIS_Results <- himasis(Y, M, X, COV.MY, glm.family = Y.family, modelstatement = "Y ~ Mone + X", 
+                               parallel = parallel, ncore = ncore, verbose, tag = paste0("Sure Independent Screening (Y ~ M + X + COV.MY, family: ", Y.family, ")"))
       SIS_Pvalue <- SIS_Results[2,]
     } else {
-      stop(paste0("Family ", family, " is not supported."))
+      stop(paste0("Family ", Y.family, " is not supported."))
     }
+    
     # Note: ranking using p on un-standardized data is equivalent to ranking using beta on standardized data
     SIS_Pvalue_sort <- sort(SIS_Pvalue)
     ID <- which(SIS_Pvalue <= SIS_Pvalue_sort[d])  # the index of top mediators
@@ -146,17 +143,17 @@ hima <- function(X, Y, M, COV.XM = NULL, COV.MY = COV.XM,
     message("Step 2: Penalized estimate (", penalty, ") ...", "     (", Sys.time(), ")")
     
     ## Based on the screening results in step 1. We will find the most influential M on Y.
-    if (is.null(COV.MY)) {
-      fit <- ncvreg(XM, Y, family = family, 
+    if(is.null(COV.MY)) {
+      fit <- ncvreg(XM, Y, family = Y.family, 
                     penalty = penalty, 
                     penalty.factor = c(rep(1, ncol(M_SIS)), 0), ...)
     } else {
       COV.MY <- data.frame(COV.MY)
       COV.MY <- data.frame(model.matrix(~., COV.MY))[, -1]
       conf.names <- colnames(COV.MY)
-      if (verbose) message("    Adjusting for covariate(s): ", paste0(conf.names, collapse = ", "))
+      if(verbose) message("    Adjusting for covariate(s): ", paste0(conf.names, collapse = ", "))
       XM_COV <- cbind(XM, COV.MY)
-      fit <- ncvreg(XM_COV, Y, family = family, 
+      fit <- ncvreg(XM_COV, Y, family = Y.family, 
                     penalty = penalty, 
                     penalty.factor = c(rep(1, ncol(M_SIS)), rep(0, 1 + ncol(COV.MY))), ...)
     }
@@ -169,22 +166,26 @@ hima <- function(X, Y, M, COV.XM = NULL, COV.MY = COV.XM,
     ID_1_non <- which(est != 0)
     if(length(ID_1_non) == 0)
     {
-      if(verbose) message("    All ", penalty, " beta estimates of the ", length(ID), " mediators are zero. Please check ncvreg package for more options (?ncvreg).")
+      if(verbose) message("    All ", penalty, " beta estimates of the ", length(ID), " mediators are zero. 
+                          Please check ncvreg package for more options (?ncvreg).")
     } else {
     if(verbose) message("    Non-zero ", penalty, " beta estimate(s) of mediator(s) found: ", paste0(names(ID_1_non), collapse = ","))
     beta_est <- est[ID_1_non]  # The non-zero MCP estimators of beta
     ID_test <- ID[ID_1_non]  # The index of the ID of non-zero beta in Y ~ M
     ## 
     
-    if(family == "binomial")
+    if(Y.family == "binomial")
     {
-      ## This has been done in step 1 (when Y is binary)
-      alpha <- alpha[,ID_test, drop = FALSE]
-    } else {
+      ## This has been done in step 1 (when Y is binary, alpha is estimated in M ~ X)
+      alpha <- alpha[, ID_test, drop = FALSE]
+      message("    Using alpha estimated in Step 1 ...   (", Sys.time(), ")")
+    } else if(Y.family == "gaussian"){
       if(verbose) message("    Estimating alpha (effect of X on M): ", appendLF = FALSE)
-      alpha <- himasis(NA, M[, ID_test, drop = FALSE], X, COV.XM, glm.family = "gaussian", 
+      alpha <- himasis(NA, M[, ID_test, drop = FALSE], X, COV.XM, glm.family = M.family, 
                        modelstatement = "Mone ~ X", parallel = FALSE, ncore = ncore, 
-                       verbose, tag = "site-by-site ordinary least squares estimation")
+                       verbose, tag = paste0("site-by-site alpha estimation (M ~ X + COV.XM, family: ", M.family, ")"))
+    } else {
+      stop(paste0("Family ", Y.family, " is not supported."))
     }
     
     #########################################################################
@@ -200,13 +201,13 @@ hima <- function(X, Y, M, COV.XM = NULL, COV.MY = COV.XM,
     alpha_est <- alpha_est_ID_test
     
     ## Post-test based on the oracle property of the MCP penalty
-    if (is.null(COV.MY)) {
+    if(is.null(COV.MY)) {
       YMX <- data.frame(Y = Y, M[, ID_test, drop = FALSE], X = X)
     } else {
       YMX <- data.frame(Y = Y, M[, ID_test, drop = FALSE], X = X, COV.MY)
     }
     
-    res <- summary(glm(Y ~ ., family = family, data = YMX))$coefficients
+    res <- summary(glm(Y ~ ., family = Y.family, data = YMX))$coefficients
     est <- res[2:(length(ID_test) + 1), 1]  # the estimator for beta
     P_adjust_beta <- length(ID_test) * res[2:(length(ID_test) + 1), 4]  # the adjused p-value for beta (bonferroni)
     P_adjust_beta[P_adjust_beta > 1] <- 1
@@ -222,13 +223,13 @@ hima <- function(X, Y, M, COV.XM = NULL, COV.MY = COV.XM,
     FDR <- apply(FDRA, 2, max)
     
     # Total effect
-    if (is.null(COV.MY)) {
+    if(is.null(COV.MY)) {
       YX <- data.frame(Y = Y, X = X)
     } else {
       YX <- data.frame(Y = Y, X = X, COV.MY)
     }
     
-    gamma_est <- coef(glm(Y ~ ., family = family, data = YX))[2]
+    gamma_est <- coef(glm(Y ~ ., family = Y.family, data = YX))[2]
     
     results <- data.frame(alpha = alpha_est, beta = beta_est, gamma = gamma_est, 
                           `alpha*beta` = ab_est, `% total effect` = ab_est/gamma_est * 100, 
